function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var observable_1 = require("tns-core-modules/data/observable/observable");
var utils_1 = require("tns-core-modules/utils/utils");
var tns_custom_scrolling_layout_callback_1 = require("./tns-custom-scrolling-layout-callback");
var tns_wear_os_adapter_1 = require("./tns-wear-os-adapter");
var tns_wearable_recyclerview_1 = require("./tns-wearable-recyclerview");
var BASE = require("./wear-os-listview-base");
__export(require("./wear-os-listview-base"));
var WearOsListView = (function (_super) {
    __extends(WearOsListView, _super);
    function WearOsListView() {
        var _this = _super.call(this) || this;
        _this.circularScrollingEnabled = false;
        _this._realizedItems = new Map();
        _this._androidViewId = -1;
        return _this;
    }
    Object.defineProperty(WearOsListView.prototype, "android", {
        get: function () {
            return this.listView;
        },
        enumerable: true,
        configurable: true
    });
    WearOsListView.prototype.createNativeView = function () {
        this._itemsSelected = [];
        this._staggeredMap = new Map();
        this._random = new java.util.Random();
        this.listView = new tns_wearable_recyclerview_1.TNS_WearableRecyclerView(this._context, new WeakRef(this));
        return this.listView;
    };
    WearOsListView.prototype.initNativeView = function () {
        _super.prototype.initNativeView.call(this);
        var that = new WeakRef(this);
        this.nativeViewProtected.setEnabled(false);
        if (this._androidViewId < 0) {
            this._androidViewId = android.view.View.generateViewId();
        }
        this.nativeViewProtected.setId(this._androidViewId);
        this.listView.setEdgeItemsCenteringEnabled(true);
        tns_wear_os_adapter_1.ensureWearOsListViewAdapterClass();
        var adapter = new tns_wear_os_adapter_1.TNS_WearOsListViewAdapterClass(new WeakRef(this));
        adapter.owner = that;
        adapter.setHasStableIds(true);
        this.listView.setAdapter(adapter);
        this.listView.adapter = adapter;
        var androidConfig = utils_1.ad.getApplicationContext()
            .getResources()
            .getConfiguration();
        var isCircleWatch = androidConfig.isScreenRound();
        if (isCircleWatch === true) {
            var customScrollingLayoutCallback = new tns_custom_scrolling_layout_callback_1.TNS_CustomScrollingLayoutCallback();
            this.listView.setLayoutManager(new android.support.wear.widget.WearableLinearLayoutManager(this._context, customScrollingLayoutCallback));
        }
        else {
            this.listView.setLayoutManager(new android.support.wear.widget.WearableLinearLayoutManager(this._context));
        }
        if (this.circularScrollingEnabled === true) {
            this.listView.setCircularScrollingGestureEnabled(true);
        }
        var params = new android.support.v7.widget.RecyclerView.LayoutParams(android.support.v7.widget.RecyclerView.LayoutParams.MATCH_PARENT, android.support.v7.widget.RecyclerView.LayoutParams.MATCH_PARENT);
        this.listView.setLayoutParams(params);
        this.listView.setVerticalScrollBarEnabled(true);
        this.listView.setScrollBarSize(20);
        BASE.itemWidthProperty.coerce(this);
        BASE.itemHeightProperty.coerce(this);
    };
    WearOsListView.prototype.disposeNativeView = function () {
        var nativeView = this.nativeViewProtected;
        nativeView.setAdapter(null);
        this.eachChildView(function (view) {
            if (view && view.parent) {
                view.parent._removeView(view);
            }
            return true;
        });
        nativeView.adapter.owner = null;
        this._clearRealizedCells();
        _super.prototype.disposeNativeView.call(this);
    };
    WearOsListView.prototype.onLoaded = function () {
        _super.prototype.onLoaded.call(this);
        this.requestLayout();
    };
    WearOsListView.prototype.onLayout = function (left, top, right, bottom) {
        _super.prototype.onLayout.call(this, left, top, right, bottom);
        this.refresh();
    };
    WearOsListView.prototype.refresh = function () {
        var nativeView = this.listView;
        if (!nativeView || !nativeView.getAdapter()) {
            return;
        }
        this._realizedItems.forEach(function (view, nativeView) {
            if (!(view.bindingContext instanceof observable_1.Observable)) {
                view.bindingContext = null;
            }
        });
        nativeView.getAdapter().notifyDataSetChanged();
    };
    WearOsListView.prototype.scrollToIndex = function (index) {
        var nativeView = this.nativeViewProtected;
        if (nativeView) {
            nativeView.setSelection(index);
        }
    };
    WearOsListView.prototype.scrollToIndexAnimated = function (index) {
        var nativeView = this.nativeViewProtected;
        if (nativeView) {
            nativeView.smoothScrollToPosition(index);
        }
    };
    Object.defineProperty(WearOsListView.prototype, "_childrenCount", {
        get: function () {
            return this._realizedItems.size;
        },
        enumerable: true,
        configurable: true
    });
    WearOsListView.prototype.eachChildView = function (callback) {
        this._realizedItems.forEach(function (view, nativeView) {
            if (view.parent instanceof WearOsListView) {
                callback(view);
            }
            else {
                if (view.parent) {
                    callback(view.parent);
                }
            }
        });
    };
    WearOsListView.prototype._clearRealizedCells = function () {
        var _this = this;
        this._realizedItems.forEach(function (view, nativeView) {
            if (view.parent) {
                if (!(view.parent instanceof WearOsListView)) {
                    _this._removeView(view.parent);
                }
                view.parent._removeView(view);
            }
        });
        this._realizedItems.clear();
        this._staggeredMap.clear();
    };
    WearOsListView.prototype[BASE.itemTemplatesProperty.getDefault] = function () {
        return null;
    };
    WearOsListView.prototype[BASE.itemTemplatesProperty.setNative] = function (value) {
        this._itemTemplatesInternal = new Array(this._defaultTemplate);
        if (value) {
            this._itemTemplatesInternal = this._itemTemplatesInternal.concat(value);
        }
        this.listView.setAdapter(new tns_wear_os_adapter_1.TNS_WearOsListViewAdapterClass(new WeakRef(this)));
        this.refresh();
    };
    WearOsListView.itemLoadingEvent = BASE.ITEMLOADING;
    WearOsListView.itemTapEvent = BASE.ITEMTAP;
    return WearOsListView;
}(BASE.WearOsListViewBase));
exports.WearOsListView = WearOsListView;
